%define anolis_release 2

%bcond_with tests
%bcond_with doc

%global pypi_name pip
%global bashcompdir %(pkg-config --variable=completionsdir bash-completion 2>/dev/null)

Name:           python-pip
Version:        23.3.1
Release:        %{anolis_release}%{?dist}
Summary:        A tool for installing and managing Python package 
License:        MIT AND Python-2.0.1 AND Apache-2.0 AND BSD-2-Clause AND BSD-3-Clause AND ISC AND LGPL-2.1-only AND MPL-2.0 AND (Apache-2.0 OR BSD-2-Clause)
URL:            https://pip.pypa.io/
Source0:        https://github.com/pypa/pip/archive/%{version}/%{pypi_name}-%{version}.tar.gz
Source1:        pip.aliyun.conf
Source2:	pip.loongarch.conf
Source10:       0005-pip-allow-different-versions.patch

BuildArch:      noarch
BuildRequires:  pkgconfig(python3)
%if %{with tests}
BuildRequires:  git-core mercurial subversion breezy
BuildRequires:  python-setuptools-wheel python-wheel-wheel
%endif

Patch0001:      0001-remove-existing-dist-only-if-path-conflicts.patch
Patch0002:      0002-dummy-certifi.patch
Patch0003:      0003-nowarn-pip._internal.main.patch
Patch0004:      0004-no-version-warning.patch

%global bundled() %{expand:
Provides: bundled(python%{1}dist(cachecontrol)) = 0.13.1
Provides: bundled(python%{1}dist(certifi)) = 2023.7.22
Provides: bundled(python%{1}dist(chardet)) = 5.1
Provides: bundled(python%{1}dist(colorama)) = 0.4.6
Provides: bundled(python%{1}dist(distlib)) = 0.3.6
Provides: bundled(python%{1}dist(distro)) = 1.8
Provides: bundled(python%{1}dist(idna)) = 3.4
Provides: bundled(python%{1}dist(msgpack)) = 1.0.5
Provides: bundled(python%{1}dist(packaging)) = 21.3
Provides: bundled(python%{1}dist(platformdirs)) = 3.8.1
Provides: bundled(python%{1}dist(pygments)) = 2.15.1
Provides: bundled(python%{1}dist(pyparsing)) = 3.1
Provides: bundled(python%{1}dist(pyproject-hooks)) = 1
Provides: bundled(python%{1}dist(requests)) = 2.31
Provides: bundled(python%{1}dist(resolvelib)) = 1.0.1
Provides: bundled(python%{1}dist(rich)) = 13.4.2
Provides: bundled(python%{1}dist(setuptools)) = 68
Provides: bundled(python%{1}dist(six)) = 1.16
Provides: bundled(python%{1}dist(tenacity)) = 8.2.2
Provides: bundled(python%{1}dist(tomli)) = 2.0.1
Provides: bundled(python%{1}dist(truststore)) = 0.8
Provides: bundled(python%{1}dist(typing-extensions)) = 4.7.1
Provides: bundled(python%{1}dist(urllib3)) = 1.26.17
Provides: bundled(python%{1}dist(webencodings)) = 0.5.1
}

%global crypt_compat_recommends() %{expand:
Recommends: (libcrypt.so.1()(64bit) if python%{1}(x86-64))
}

%description
pip is a package management system used to install and manage software packages
written in Python. Many packages can be found in the Python Package Index
(PyPI). pip is a recursive acronym that can stand for either "Pip Installs
Packages" or "Pip Installs Python".

%package -n python3-%{pypi_name}
Summary:        A tool for installing and managing Python3 packages

BuildRequires:  python3-devel python3-rpm-generators >= 11-8 ca-certificates
BuildRequires:  python3-wheel python3-setuptools pkgconfig(bash-completion)
%if %{with tests}
BuildRequires:  python3-freezegun python3-scripttest
BuildRequires:  python3-cryptography python3-mock python3-pretend
BuildRequires:  python3-werkzeug python3-virtualenv python3-pytest 
BuildRequires:  python3-tomli-w python3-pyyaml python3-installer
%endif

%{bundled 3}

Requires:       ca-certificates
Recommends:     python3-setuptools

Provides:       pip = %{version}-%{release}
Provides:       platform-python-pip = %{version}-%{release}

%description -n python3-%{pypi_name}
pip is a package management system used to install and manage software packages
written in Python. Many packages can be found in the Python Package Index
(PyPI). pip is a recursive acronym that can stand for either "Pip Installs
Packages" or "Pip Installs Python".

%package -n     %{python_wheel_pkg_prefix}-%{pypi_name}-wheel
Summary:        The pip wheel
Requires:       ca-certificates

%{bundled 3}

%{crypt_compat_recommends 3}

%description -n %{python_wheel_pkg_prefix}-%{pypi_name}-wheel
A Python wheel of pip to use with venv.

%if %{with doc}
%package -n python3-%{pypi_name}-doc
Summary:        A documentation for a tool for installing and managing Python packages

BuildRequires:  python3-sphinx python3-sphinx-inline-tabs python3-sphinx-copybutton
BuildRequires:  python3-myst-parser
Requires:       python3-%{pypi_name} = %{EVR}

%description -n python3-%{pypi_name}-doc
A documentation for a tool for installing and managing Python packages
%endif

%prep
%autosetup -n %{pypi_name}-%{version} -p1

rm src/pip/_vendor/certifi/*.pem
sed -i '/html_theme = "furo"/d' docs/html/conf.py
sed -i '/"sphinxcontrib.towncrier",/d' docs/html/conf.py
ln -s %{python_wheel_dir} tests/data/common_wheels
rm -v src/pip/_vendor/distlib/*.exe
sed -i '/\.exe/d' setup.py

%build
%py3_build_wheel

%if %{with doc}
export PYTHONPATH=./src/
sphinx-build-3 -b html docs/html docs/build/html
sphinx-build-3 -b man  docs/man  docs/build/man -c docs/html
rm -rf docs/build/html/{.doctrees,.buildinfo}
%endif

%install
%{python3} dist/%{pypi_name}-%{version}-py3-none-any.whl/pip install \
    --root %{buildroot} \
    --no-deps \
    --disable-pip-version-check \
    --progress-bar off \
    --verbose \
    --ignore-installed \
    --no-warn-script-location \
    --no-index \
    --no-cache-dir \
    --find-links dist \
    'pip==%{version}'

%if %{with doc}
pushd docs/build/man
mkdir -p %{buildroot}%{_mandir}/man1
for MAN in *1; do
install -m 0644 -p $MAN %{buildroot}%{_mandir}/man1/$MAN
for pip in "pip3" "pip-3" "pip%{python3_version}" "pip-%{python3_version}"; do
echo ".so $MAN" > %{buildroot}%{_mandir}/man1/${MAN/pip/$pip}
done
done
popd
%endif

# before we ln -s anything, we apply Source10 patch to all pips:
for PIP in %{buildroot}%{_bindir}/pip*; do
  patch -p1 --no-backup-if-mismatch $PIP < %{SOURCE10}
done

mkdir -p %{buildroot}%{bashcompdir}
PYTHONPATH=%{buildroot}%{python3_sitelib} \
    %{buildroot}%{_bindir}/pip completion --bash \
    > %{buildroot}%{bashcompdir}/pip3

sed -i -e "s/^\\(complete.*\\) pip\$/\\1 pip pip{,-}{3,%{python3_version}}/" \
    -e s/_pip_completion/_pip3_completion/ \
    %{buildroot}%{bashcompdir}/pip3


ln -s ./pip%{python3_version} %{buildroot}%{_bindir}/pip-%{python3_version}
ln -s ./pip-%{python3_version} %{buildroot}%{_bindir}/pip-3


echo rpm > %{buildroot}%{python3_sitelib}/pip-%{version}.dist-info/INSTALLER
rm %{buildroot}%{python3_sitelib}/pip-%{version}.dist-info/RECORD

mkdir -p %{buildroot}%{python_wheel_dir}
install -p dist/%{pypi_name}-%{version}-py3-none-any.whl -t %{buildroot}%{python_wheel_dir}

%ifarch loongarch64
install -D -m0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/pip.conf
%else
install -D -m0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/pip.conf
%endif

%if %{with tests}
%check
%{_rpmconfigdir}/pythonbundles.py src/pip/_vendor/vendor.txt --compare-with '%{bundled 3}'

pytest_k='not completion'

%pytest -m 'not network' -k "$(echo $pytest_k)" \
    --deselect tests/functional --deselect tests/lib/test_lib.py --deselect tests/unit/test_build_env.py
%endif

%files -n python3-%{pypi_name}
%license LICENSE.txt
%config(noreplace) %{_sysconfdir}/pip.conf
%{_bindir}/pip
%{_bindir}/pip3
%{_bindir}/pip-3
%{_bindir}/pip%{python3_version}
%{_bindir}/pip-%{python3_version}
%{python3_sitelib}/pip*
%dir %{bashcompdir}
%{bashcompdir}/pip3
%if %{with doc}
%{_mandir}/man1/pip.*
%{_mandir}/man1/pip-*.*
%{_mandir}/man1/pip3.*
%{_mandir}/man1/pip3-*.*
%endif

%files -n %{python_wheel_pkg_prefix}-%{pypi_name}-wheel
%license LICENSE.txt
%dir %{python_wheel_dir}/
%{python_wheel_dir}/%{pypi_name}-%{version}-py3-none-any.whl

%if %{with doc}
%files -n python3-%{pypi_name}-doc
%doc README.rst docs/build/html
%endif

%changelog
* Tue Mar 12 2024 Zhao Hang <wb-zh951434@alibaba-inc.com> - 23.3.1-2
- Rebuild with python3.11

* Thu Oct 26 2023 Funda Wang <fundawang@yeah.net> - 23.3.1-1
- New verison 23.3.1

* Thu Jul 27 2023 Funda Wang <fundawang@yeah.net> - 23.2.1-1
- New version 23.2.1

* Wed Apr 19 2023 Funda Wang <fundawang@yeah.net> - 23.1-1
- New version 23.1

* Tue Apr 11 2023 yuanhui <yuanhui@linux.alibaba.com> - 23.0.1-3
- Optimize the spec file

* Tue Mar 28 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 23.0.1-2
- Del Specific Fields

* Thu Mar 02 2023 Funda Wang <fundawang@yeah.net> - 23.0.1-1
- New version 23.0.1
- Default to aliyun.com mirror for pip

* Mon Jan 23 2023 Funda Wang <fundawang@yeah.net> - 22.3.1-1
- New version 22.3.1

* Mon Mar 14 2022 forrest_ly <flin@linux.alibaba.com> - 22.0.4-1
- Init for Anolis OS 23
